..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Developer API
=============

This chapter contains API specifications which are relevant to BayesPy
developers and contributors.

.. toctree::
    :maxdepth: 1
    
    nodes
    moments
    distributions
    utils
    

